package com.mysql.jdbc;

import com.mysql.jdbc.ServerPreparedStatement;
import java.io.Reader;
import java.sql.NClob;
import java.sql.SQLException;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/JDBC4ServerPreparedStatement.class */
public class JDBC4ServerPreparedStatement extends ServerPreparedStatement {
    public JDBC4ServerPreparedStatement(ConnectionImpl conn, String sql, String catalog, int resultSetType, int resultSetConcurrency) throws SQLException {
        super(conn, sql, catalog, resultSetType, resultSetConcurrency);
    }

    @Override // com.mysql.jdbc.PreparedStatement, java.sql.PreparedStatement
    public void setNCharacterStream(int parameterIndex, Reader reader, long length) throws SQLException {
        if (!this.charEncoding.equalsIgnoreCase("UTF-8") && !this.charEncoding.equalsIgnoreCase("utf8")) {
            throw SQLError.createSQLException("Can not call setNCharacterStream() when connection character set isn't UTF-8");
        }
        checkClosed();
        if (reader == null) {
            setNull(parameterIndex, -2);
            return;
        }
        ServerPreparedStatement.BindValue binding = getBinding(parameterIndex, true);
        setType(binding, MysqlDefs.FIELD_TYPE_BLOB);
        binding.value = reader;
        binding.isNull = false;
        binding.isLongData = true;
        if (this.connection.getUseStreamLengthsInPrepStmts()) {
            binding.bindLength = length;
        } else {
            binding.bindLength = -1L;
        }
    }

    @Override // java.sql.PreparedStatement
    public void setNClob(int parameterIndex, NClob x) throws SQLException {
        setNClob(parameterIndex, x.getCharacterStream(), this.connection.getUseStreamLengthsInPrepStmts() ? x.length() : -1L);
    }

    @Override // com.mysql.jdbc.PreparedStatement, java.sql.PreparedStatement
    public void setNClob(int parameterIndex, Reader reader, long length) throws SQLException {
        if (!this.charEncoding.equalsIgnoreCase("UTF-8") && !this.charEncoding.equalsIgnoreCase("utf8")) {
            throw SQLError.createSQLException("Can not call setNClob() when connection character set isn't UTF-8");
        }
        checkClosed();
        if (reader == null) {
            setNull(parameterIndex, 2011);
            return;
        }
        ServerPreparedStatement.BindValue binding = getBinding(parameterIndex, true);
        setType(binding, MysqlDefs.FIELD_TYPE_BLOB);
        binding.value = reader;
        binding.isNull = false;
        binding.isLongData = true;
        if (this.connection.getUseStreamLengthsInPrepStmts()) {
            binding.bindLength = length;
        } else {
            binding.bindLength = -1L;
        }
    }

    @Override // com.mysql.jdbc.PreparedStatement, java.sql.PreparedStatement
    public void setNString(int parameterIndex, String x) throws SQLException {
        if (this.charEncoding.equalsIgnoreCase("UTF-8") || this.charEncoding.equalsIgnoreCase("utf8")) {
            setString(parameterIndex, x);
            return;
        }
        throw SQLError.createSQLException("Can not call setNString() when connection character set isn't UTF-8");
    }
}
